Output
------

Problematic
^^^^^^^^^^^

How can we generate or work with outputs ?

Documentation
^^^^^^^^^^^^^

.. automodule:: PyFunceble.output
   :members:
   :private-members:

:code:`Clean()`
"""""""""""""""

.. autoclass:: PyFunceble.output.clean.Clean
    :members:
    :private-members:

:code:`Constructor()`
"""""""""""""""""""""

.. autoclass:: PyFunceble.output.constructor.Constructor
    :members:
    :private-members:

:code:`Generate()`
""""""""""""""""""

.. autoclass:: PyFunceble.output.generate.Generate
    :members:
    :private-members:

:code:`Logs()`
""""""""""""""

.. autoclass:: PyFunceble.output.logs.Logs
    :members:
    :private-members:

:code:`Percentage()`
""""""""""""""""""""

.. autoclass:: PyFunceble.output.percentage.Percentage
    :members:
    :private-members:

:code:`Prints()`
""""""""""""""""

.. autoclass:: PyFunceble.output.prints.Prints
    :members:
    :private-members: